pub struct Summary {
pub total_offer_count: i32,
pub number_of_offers: Option<Vec<OfferCountType>>,
pub lowest_prices: Option<Vec<LowestPriceType>>,
pub buy_box_prices: Option<Vec<BuyBoxPriceType>>,
pub list_price: Option<Box<MoneyType>>,
pub competitive_price_threshold: Option<Box<MoneyType>>,
pub suggested_lower_price_plus_shipping: Option<Box<MoneyType>>,
pub sales_rankings: Option<Vec<SalesRankType>>,
pub buy_box_eligible_offers: Option<Vec<OfferCountType>>,
pub offers_available_time: Option<String>,
}Expand description
Summary : Contains price information about the product, including the LowestPrices and BuyBoxPrices, the ListPrice, the SuggestedLowerPricePlusShipping, and NumberOfOffers and NumberOfBuyBoxEligibleOffers.
Fields
total_offer_count: i32The number of unique offers contained in NumberOfOffers.
number_of_offers: Option<Vec<OfferCountType>>lowest_prices: Option<Vec<LowestPriceType>>buy_box_prices: Option<Vec<BuyBoxPriceType>>list_price: Option<Box<MoneyType>>competitive_price_threshold: Option<Box<MoneyType>>suggested_lower_price_plus_shipping: Option<Box<MoneyType>>sales_rankings: Option<Vec<SalesRankType>>A list of sales rank information for the item, by category.
buy_box_eligible_offers: Option<Vec<OfferCountType>>offers_available_time: Option<String>When the status is ActiveButTooSoonForProcessing, this is the time when the offers will be available for processing.
Implementations